@@ -17,7 +17,7 @@ if(lnAUC0INF){
 cat("**Interpretation:\n")
 cat("Ho: Theta < ",formatC(theta1,format="f",digits=5)," or  Theta > ",formatC(theta2,format="f",digits=5), "\n")
 cat("Ha: ",formatC(theta1,format="f",digits=5)," < or = Theta < or = ",formatC(theta2,format="f",digits=5),"\n")
-cat("where Theta = Mean_test/Mean_ref.\n")
+cat("where Theta = Mean_Test/Mean_Ref.\n")
 cat("Because at least one of P values is greater than 0.05, we thus can not reject\n")
 cat("the null hypothesis (Ho). \n")
 cat("BE acceptance criterion is set within the range of ",formatC(theta1*100,format="f",digits=3)," - ",formatC(theta2*100,format="f",digits=3),"% .\n")
