@@ -10,7 +10,7 @@ cat(" The inflection point of the curve describes the point where the algebraic
 cat(" sign of the curvature changes. Tinpt is equal to two times Tmax.  Thus,      \n")
 cat(" The twofold of the observed Tmax value can be used as a threshold of time    \n")
 cat(" points to be included in the calculation of lambda(z).  Then, within that    \n")
-cat(" range, we apply maximun ARS values to get best fit. It starts with the last  \n")
+cat(" range, we apply maximum ARS values to get best fit. It starts with the last  \n")
 cat(" three data points from the concentration-time profile, performing log-linear \n")
 cat(" regression to calculate the slope of that tail portion of the concentration- \n")
 cat(" time curve.  And then the last 4 data points, the last 5 data points, on and \n")
