@@ -1,7 +1,7 @@
 description_drug<-function(){
 cat("****************************************************************************\n")
-cat("     drug# 1: Ref.                                                          \n")
-cat("     drug# 2: Test                                                          \n")
+cat("     drug/trt. code#1: Ref. product                                         \n")
+cat("     drug/trt. code#2: Test product                                         \n")
 cat("****************************************************************************\n")
 cat("\n")
 }
