@@ -11,11 +11,11 @@ d88       88   d8(        )8b             )8b     888     8)
 888       88   888ooo88b   o8o89888     888
 888       88   888              88(        88     888
  o8ooo8         88bod8P     doooo888   d888b", cex=0.8, adj=c(0,0))
-text(100,180,"This report was generated using bear v2.5.5",cex = 1.2)
+text(100,180,"This report was generated using bear v2.5.6",cex = 1.2)
 text(70,170,"on:",cex=1.2)
 text(110,170,Sys.time(),cex = 1.2)
 text(100,150,
-"bear was developed by Hsin-ya Lee (HY) & Yung-jin Lee (YJ).",cex = 1.2)
+"bear is developed by Hsin-ya Lee (HY) & Yung-jin Lee (YJ).",cex = 1.2)
 text(100,130,
 "Kaohsiung Veterans General Hospital (HY) &",cex = 1.2)
 text(100,120,
