@@ -32,7 +32,7 @@ cat("\n")
     else {
     if (pick == 5){
         cat("\n")
-       go() 
+       go2menu() 
          }          
     else {
     if (pick == 6){
