@@ -18,7 +18,7 @@ cat(" press 'Enter' or 'Return' key lots of times to continue. It will not\n")
 cat(" happen to real runs. It is just default setting for demo mode in R.\n")
 cat(" You have to click R console first and then press 'Enter' or 'Return'\n")
 cat(" key sometimes if the screen seems keeping freezed there.\n\n")
-cat(" This demo will load raw data from backgroud. So it will start from\n")
+cat(" This demo will load raw data from background. So it will start from\n")
 cat(" from method selection of lambda_z estimation, then do NCA and\n")
 cat(" finally perform statistical analysis with NCA results, together\n")
 cat(" with some plots showing, as well as generating output files.\n\n")
